@@ -4,6 +4,7 @@
 import subprocess
 import sys
 from collections import OrderedDict
+from typing import Optional, List
 
 
 class Git:
@@ -18,14 +19,18 @@ class Git:
         pretend = is_write and self._pretend
         if self._verbose:
             epilog = '   # skipped due to --pretend' if pretend else ''
-            print(f'# {" ".join(argv)}{epilog}', file=sys.stderr)
+            display_argv = [a for a in argv if not a.startswith('--format=')]
+            print(f'# {" ".join(display_argv)}{epilog}', file=sys.stderr)
         if pretend:
             return bytes()
         return subprocess.check_output(argv)
 
     @classmethod
-    def _output_bytes_to_lines(cls, output_bytes):
-        return output_bytes.decode('utf-8').rstrip().split('\n')
+    def _output_bytes_to_lines(cls, output_bytes) -> List[str]:
+        text = output_bytes.decode('utf-8').rstrip()
+        if not text:  # protect against this: ''.split('\n') -> ['']
+            return []
+        return text.split('\n')
 
     def extract_git_config(self):
         argv = [self._GIT, 'config', '--list']
@@ -53,7 +58,8 @@ class Git:
         if extra_argv is not None:
             argv += extra_argv
         output_bytes = self._subprocess_check_output(argv, is_write=False)
-        return self._output_bytes_to_lines(output_bytes)
+        lines = self._output_bytes_to_lines(output_bytes)
+        return [l for l in lines if not l.endswith('/HEAD')]
 
     def find_local_branches(self):
         return self._find_branches()
@@ -61,6 +67,13 @@ class Git:
     def find_all_branches(self):
         return self._find_branches(['--all'])
 
+    def find_current_branch(self) -> Optional[str]:
+        branch_names = self._find_branches(['--show-current'])
+        if not branch_names:
+            return None
+        assert len(branch_names) == 1
+        return branch_names[0]
+
     def _get_merged_branches_for(self, target_branch: str, remote: bool):
         extra_argv = []
         if remote:
